--=============================================================================
-- File:           create_tables.sql
-- Description:    Creates demo tables that use the SAIF schema
--                 and the Santa Barbara alerter.
-- Dependencies:   The SAIF schema in ../src must already be loaded.
-- $Id: create_tables.sql,v 1.3 1994/10/27 16:18:16 jta Exp $
--=============================================================================

-- Create a rasters table. 
-- Since all rasters in this particular dataset share the same grid, we 
-- inherit just Raster instead of GeneralRaster and create reference to
-- that Grid.
--
-- 'rasters' will look like this:
--
--	rasters:
--		contentValues       image 
--		rtime               int
--		frequency           int
--	        sample_bytes        int
--              grid                oid pointer to Grid
--
--      Grid:
--		positionOfOrigin    CoordXY_t        \
--		orderAndOrigin      GridReference_t   | Grid
--		spacing             GridFramework_t   |
--              cellGeometry        CellGeometry_t   /

create table rasters (
	rtime        int,
	frequency    int,
	sample_bytes int,
        grid         ref(Grid_t)
) under Raster;


--
-- Create point and polygon tables (from $MI_HOME/examples/sequoia2000)
--

create table points (location Pnt, name text, county text);
create table polygons (landuse int, location Poly);
create table islands (location Poly);

--
-- Create an audit table for our alerter
--
create table s2k_audit (
        s2k_rule        text,   -- name of the rule that fired (rules.rule_name)
        s2k_user        text,   -- user that caused rule to fire
        s2k_obj         text,   -- name of object rule is on (rules.rule_table)
        s2k_ops         char,   -- (d)elete, (i)insert, (s)elect, (u)pdate
        s2k_info        text,   -- any additional info
        s2k_date        abstime -- date & time rule fired
        );

--
-- alerters and alerter rules
--
create alerter SantaB (mechanism = 'callback');

create rule sb_select_rule on
        select to points where current.county = 'Santa Barbara'
        do
                begin
                        insert into s2k_audit
                        values(
                                'sb_rule',
                                user,
                                'points',
                                's',
                                current.name,
                                'now');
                        alert SantaB;
                end ;

create rule sb_delete_rule on
        delete to points where current.county = 'Santa Barbara'
        do
                begin
                        insert into s2k_audit
                        values(
                                'sb_rule',
                                user,
                                'points',
                                'd',
                                current.name,
                                'now');
                        alert SantaB;
                end ;
