--=============================================================================
-- File:           load_data.sql
-- Description:    Loads data into the database.
-- Dependencies:   The Makefile does the following:
--                    loads the SAIF schema in ../src
--                    loads ./create_tables.sql
--                    expands __DEMO_DIR__ below to `pwd` then runs it
-- $Id: load_data.sql,v 1.3 1994/10/27 16:18:28 jta Exp $
--=============================================================================

--
-- Load the Grid that all rasters share.
--

insert into Grid
(       positionOfOrigin,               -- CoordXY_t
        orderAndOrigin,                 -- GridReference_t
        spacing,                        -- GridFramework_t
        cellGeometry                    -- CellGeometry_t
)
values
(       '(-16000, -2029000)',           -- easting/northing at ne corner
        GridReference_t
        (       'rowOrder',             -- ordering (GridOrder enum)
                'ne',                   -- originCorner (OriginReference enum)
                't',                    -- cellPostitionAtCorner (F = center)
                '[0, 0]'                -- originCoordinates
        ),
        GridFramework_t
        (       '[2560, 1600]',         -- gridDimensions
                '[500, 500]',           -- gridSpacing
                'none',                 -- offsetStructure (OffsetStructure)
                '[metres, metres]'      -- unit (UnitMeaning enum)
        ),
        CellGeometry_t
        (       '[500, 500]',           -- cellSize
                '[metres, metres]',     -- UnitMeaning
                'rectangle'             -- CellShape
        )
);

--
-- Load rasters
--

insert into rasters 
(    contentValues,          -- image
     rtime,
     frequency,
     sample_bytes
) 
values
(
     'format(pgm):__DEMO_DIR__/data/p01ch5.pgm',
     01,
     05,
     01
);

insert into rasters (contentValues, rtime, frequency, sample_bytes)
values ('format(pgm):__DEMO_DIR__/data/p02ch5.pgm', 02, 05, 01);

insert into rasters (contentValues, rtime, frequency, sample_bytes)
values ( 'format(pgm):__DEMO_DIR__/data/p03ch5.pgm', 03, 05, 01);

update rasters set grid = (select unique ref(g1) from Grid g1);

-- demo gags: The first photo is color, the second is grayscale.
-- We tag our gags with rtime={4,5}, which is bogus, but then most gags
-- are bogus.
insert into rasters (contentValues, rtime) values
(    'format(ppm):__DEMO_DIR__/data/stone.ppm',
     04
);

insert into rasters (contentValues, rtime) values
(    'format(pgm):__DEMO_DIR__/data/stone.pgm',
     05
);

--
-- Point and polygon data
--
micopy polygons from '__DEMO_DIR__/data/polygons.data';

micopy islands from '__DEMO_DIR__/data/islands.data';

micopy points from '__DEMO_DIR__/data/points.data';
