--
--  Sample table for Satellite images.
--
create table SatelliteRaster (
   sensor      varchar(20),             -- e.g.: avhrr, tm, mss
   satellite   varchar(20),             -- e.g.: noaa-11, landsat 5
   band_num    integer,                 -- number of bands in the image
   band_names  arrayof(SatelliteBands)  -- which bands
) under GeneralRaster;

--  It ends up looking like this:
--
--  SatelliteRaster
--     contentValues       Raster:        image
--     positionOfOrigin    Grid:          Pnt
-      orderAndOrigin      Grid:          GridReference_t
--     spacing             Grid:          GridFramework_t
--     cellGeometry        Grid:          CellGeometry_t
--     indexScheme         GeneralRaster: IndexScheme
--     sensor
--     satellite
--     band_num
--     band_names
--

-- 
-- This assumes no data are on-line, so comments out inserting the image.
-- The image commented out below is actually one band (ndvi).
-- 
insert into SatelliteRaster 
(  -- contentValues,
   positionOfOrigin, 
   orderAndOrigin, 
   spacing, 
   cellGeometry, 
   indexScheme,
   sensor, 
   satellite, 
   band_num,
   band_names)
values
(  -- 'format(pgm):/data/p01ch6.pgm',
   '(2050000, 7520000)',  -- somewhere off NW coast in the Pacific ocean
   GridReference_t('rowOrder', 'ne', 'f', '[0,0]'),
   GridFramework_t('[2889,4587]', '[1000,1000]', 'none', '[metres,metres]'),
   CellGeometry_t('[1000,1000]', '[metres,metres]',  'rectangle'),
   'sequentialArray',
   'avhrr',
   'noaa-11',
   1,
   '[ndvi]'
);

--
-- Each sensor has a different set of channels
--
create table SensorChannels ( sensor varchar(20)) under Channel;

insert into SensorChannels 
       (sensor,  
        channelNumber, 
        name,       
        description)
values ('avhrr', 
        1,
        'channel1',
        'visible mainly red (0.58 - 0.68)');
        
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 2, 'channel2', 'near IR into mid (0.725 - 1.1)');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 3, 'channel3', 'thermal (3.55 - 3.93)');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 4, 'channel4', 'thermal IR (10.3 - 11.3)');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 5, 'channel5', 'thermal IR (11.5 - 12.5)');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 6, 'ndvi', 'normalized difference vegetation index');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 7, 'satellite zenith', 'angle info');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 8, 'solar zenith', 'more angle info');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 9, 'relative azimuth', 'still more angle info');
insert into SensorChannels (sensor, channelNumber, name, description)
   values ('avhrr', 10, 'image_source', 'pixel source date (composite image)');

-- $Header: /users/vis/jta/bigfoot/saif/src/RCS/SampleRaster.sql,v 1.1 1994/10/26 23:23:17 jta Exp $
