--=============================================================================
-- File:           saif2_types.sql
-- Description:    create SAIF 3.1 types
-- Dependencies:   saif1_enums.sql
-- Notes:          Permissions are at the bottom of the file.
-- Mods:           04/12/94  jta    works under Montage 2.0.9 on OSF1
--                 04/13/94  jta    changed SAIF 'numeric' types from 
--                                  integer to double precision
--                 06/20/94  jta    all composite type names get _t
--                 10/07/94  jta    Added BoundingBox and GeneralLocation
--                                  and a few SQL time types.
--                 10/20/94  jta    ElementStructure is obsolete in SAIF 3.2.
--
-- $Id: saif2_types.sql,v 1.4 1994/10/26 20:42:18 jta Exp $
--=============================================================================

create type BoundingBox_t under Box;
create cast (Box as BoundingBox_t);
create cast (BoundingBox_t as Box);

create type GeometricObject_t
(	qualifier	LocationalQualifier
);

create type Projection_t
(	category	ProjectionCategory,
	xUnits		UnitMeaning,
	yUnits		UnitMeaning
);

create type CoordinateSystem_t
(	horizontal	Projection_t
);

create type SpatialReferencing_t
(	coordSystem	CoordinateSystem_t
);

-- We replaced CoordXY_t with the Illustra Pnt, but left these here for
-- anyone who wants to use them.
create type Coordinate_t
(	x	double precision
);

create type CoordXY_t
(	y	double precision
) under Coordinate_t;

create type GridReference_t
(	ordering		GridOrder,
	originCorner		OriginReference,
	cellPostitionAtCorner	boolean,	-- false says it is at centre
	originCoordinates	arrayof(integer)-- usually (0,0) or (1,1)
);

create type GridFramework_t
(	gridDimensions	arrayof(integer),	-- first x, then y, etc.
	gridSpacing	arrayof(double precision), -- real world units (x, y)
	offsetStructure	OffsetStructure,	-- should be 'none' for most
	unit		arrayof(UnitMeaning)	-- kilometers, meters, etc.
);

create type CellGeometry_t
(	cellSize	arrayof(double precision), -- i.e.: 500 ...
	units		arrayof(UnitMeaning),	-- ... meters ...
	CellShape	CellShape		-- ... rectangle ...
);

--=========================== Time Types  ==================================--
-- time types need more work
--
-- TimeStamp is a SQL2 reserved word.
-- create type DateTime_t
-- (	TimeStamp	timestamp
-- );

create type DayTimeInterval_t 
(	days		integer 
);

create table Duration of new type Duration_t
(
	startTime	timestamp,
	lengthOfTime	integer     -- days, simple fudge for now
);

--=========================== Permissions ==================================--
grant usage on type BoundingBox_t to public;
grant usage on type CellGeometry_t to public;
grant usage on type Coordinate_t to public;
grant usage on type CoordinateSystem_t  to public;
grant usage on type CoordXY_t to public;
grant usage on type GeometricObject_t to public;
grant usage on type GridFramework_t to public;
grant usage on type GridReference_t to public;
grant usage on type Projection_t to public;
grant usage on type SpatialReferencing_t  to public;
