--=============================================================================
-- File:           saif3_tables.sql
-- Description:    Create SAIF 3.1 abstract superclasses.
-- Dependencies:   saif1_enums.sql and saif2_types.sql
-- Notes:          So far Grid is really the only solidly implemented
--                 SAIF object.
--                 Permissions are at the bottom of the file for types.
--
-- Mods:           04/12/94  jta    works under Montage 2.0.9 on OSF1
--                 06/21/94  jta    types get _t extension
--                 10/07/94  jta    replaced CoordXY with Illustra Pnt.
--                 10/20/94  jta    new in SAIF 3.2 changes: added Channel,
--                                  removed StructuredData 
--
-- $Id: saif3_tables.sql,v 1.4 1994/10/26 20:42:29 jta Exp $
--=============================================================================

create table Grid of new type Grid_t
(   positionOfOrigin  Pnt,                -- use Illustra 2D spatial blade
    orderAndOrigin    GridReference_t, 
    spacing           GridFramework_t,
    cellGeometry      CellGeometry_t
);

create table GeneralLocation of new type GeneralLocation_t
(	range		BoundingBox_t
);

create table SpatialObject of new type SpatialObject_t
(  geometry           GeometricObject_t,
   spatialReferencing SpatialReferencing_t
);

create table Channel of new type Channel_t
(
   channelNumber      integer,
   name               text,
   description        text,
   units              UnitMeaning,
   instanceType       PrimitiveInstanceType,
   bitsPerValue       integer
);

create table Raster of new type Raster_t
(
   contentValues      image
);

create table GeneralRaster of new type GeneralRaster_t
(
   indexScheme		IndexScheme
) under Raster, Grid;

--============================= Permissions ================================--
grant usage on type Channel_t to public;
grant usage on type GeneralLocation_t to public;
grant usage on type GeneralRaster_t to public;
grant usage on type Grid_t to public;
grant usage on type SpatialObject_t to public;
grant usage on type Raster_t to public;
